<template>
    <div class="bbsl-common-page" v-loading="uploading" element-loading-text="导入中"
        element-loading-spinner="el-icon-loading" element-loading-background="rgba(0, 0, 0, 0.8)">
        <div :class="['bbsl-table-search', isAdvanced ? 'advanced-search' : '']">
            <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="5">
                    <el-col :span="5">
                        <el-form-item label="设备名称">
                            <el-input maxlength="64" clearable placeholder="请输入设备名称" v-model="params.name"
                                size="medium"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="区域">
                            <el-cascader v-model="regionValue" :options="treeData" :show-all-levels="false"
                                @change="delRegion" :props="{
                                    label: 'name',
                                    value: 'id',
                                    children: 'children',
                                    checkStrictly: true,
                                }" clearable size="medium">
                            </el-cascader>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="设备状态">
                            <el-select v-model="params.status" size="medium" clearable placeholder="请选择设备状态">
                                <el-option v-for="item in deviceStatus" :key="item.value" :label="item.name"
                                    :value="item.value"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="重点设备">
                            <el-select v-model="params.important" size="medium" clearable placeholder="是否是重点设备">
                                <el-option label="一般设备" value="0"></el-option>
                                <el-option label="重点设备" value="1"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="4">
                        <el-button size="small" type="primary" icon="el-icon-search" @click="handleSearch">搜索
                        </el-button>
                        <el-button size="small" icon="el-icon-refresh" @click="handleReset">重置
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <div :class="['bbsl-table-content', isAdvanced ? 'advanced-search-table' : '']" ref="contentPanel">
            <div class="bbsl-btn-content" ref="btnPanel" style="display: flex">
                <el-button style="margin-left: 10px" type="warning" icon="el-icon-download" @click="exportKPL">
                    导出
                </el-button>
                <div class="statistics">
                    <div class="item">
                        <el-badge is-dot type="primary"></el-badge>
                        <span class="all-device">全部设备<span>{{
                            deviceInfo.allNum || 0
                                }}</span></span>
                    </div>

                    <div class="item">
                        <el-badge is-dot type="success"></el-badge>
                        <span class="all-device">正常<span>{{
                            deviceInfo.normalNum || 0
                                }}</span></span>
                    </div>
                    <div class="item">
                        <el-badge is-dot type="danger"></el-badge>
                        <span class="all-device">故障<span>{{
                            deviceInfo.failureNum || 0
                                }}</span></span>
                    </div>
                    <div class="item">
                        <el-badge is-dot type="warning"></el-badge>
                        <span class="all-device">报警：{{ deviceInfo.warnNum || 0 }}</span>
                    </div>
                    <i @click="refreshInfo" class="el-icon-refresh refresh"></i>
                </div>
            </div>
            <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="toEquipmentDetails"
                @selection-change="handleSelectionChange">
                <el-table-column type="selection" width="55"></el-table-column>
                <el-table-column type="index" width="55" label="序号"></el-table-column>
                <el-table-column min-width="120" prop="productName" label="产品名称"
                    show-overflow-tooltip></el-table-column>
                <el-table-column min-width="150" prop="name" label="设备名称" show-overflow-tooltip>
                </el-table-column>
                <el-table-column width="140" prop="outCode" label="SN码" show-overflow-tooltip></el-table-column>
                <el-table-column min-width="90" prop="areaName" label="所属区域" show-overflow-tooltip></el-table-column>
                <!-- <el-table-column min-width="100" prop="lgtd" label="经度" show-overflow-tooltip></el-table-column>
                <el-table-column min-width="100" prop="lttd" label="纬度" show-overflow-tooltip></el-table-column> -->
                <!-- <el-table-column width="100" prop="life" label="使用年限" show-overflow-tooltip>
                </el-table-column> -->
                <el-table-column width="80" prop="important" label="设备类型" show-overflow-tooltip>
                    <template slot-scope="scope">
                        <span v-if="scope.row.important == '1'">重点设备</span>
                        <span v-else-if="scope.row.important == '0'">一般设备</span>
                    </template>
                </el-table-column>
                <el-table-column prop="statusName" label="运行状态" show-overflow-tooltip width="80">
                    <template slot-scope="scope">
                        <div :style="scope.row.runStatus > 1 ? '#13ce66' : '#f56c6c'">
                            {{ !scope.row.runStatus ? '' : scope.row.runStatus > 1 ? '通信中断' : '正常' }}
                        </div>
                    </template>
                </el-table-column>
            </el-table>
            <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                @size-change="handleSizeChange" @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total"></el-pagination>
        </div>
        <EquipmentExtendDialog v-if="showExtend" :parameter="parameters" :showExtend="showExtend" @reload="reload"
            @closeExtend="closeExtend"></EquipmentExtendDialog>
    </div>
</template>

<script>
import { mapState } from 'vuex'
import { TableMixin } from '@/mixins/tableMixin'
import EquipmentExtendDialog from '@/views/Device/deviceManage/components/EquipmentExtendDialog'
import resourceManage from '@/api/device/resourceManage.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import utils from '@/utils.js'
import utilsHT from '@/hotent-ui-util.js'

export default {
    name: 'EquipmentMonitoring',
    components: {
        EquipmentExtendDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            importVisible: false,
            uploading: false,
            reviseDat: '',
            reviseVisible: false,
            reviseStart: '',
            exportParam: {},
            //携带参数
            uploadData: {
                productId: '',
            },
            url: {
                delete: '/device/info/',
            },
            treeData: [],
            productValue: [],
            regionValue: [],
            showMore: false,
            parameters: {},
            showExtend: false,
            params: {
                name: '',
                productId: '', //产品
                status: '', //状态
                important: '', //重点设备
                areaId: '', //区域
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'd.name_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'product_id_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'status',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'd.code_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'important',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'areaId',
                    relation: 'AND',
                    value: '',
                },
            ],
            deviceStatus: [], // 设备状态
            productData: [], // 产品数据
            flagList: [], //禁用标识字段列表
            addressTypeList: [], //安装地点类型字段列表
            productIdInfo: '',
            deviceInfo: {
                0: '',
                1: '',
                2: '',
                3: '',
                9: '',
                10: '',
            }, //设备状态数量
        }
    },
    //获取token
    computed: mapState({
        header: (state) => {
            return {
                Authorization: `Bearer ${state.login.currentUser.token}`,
            }
        },
    }),
    created() {
        //在created里面区获取actionUrl
        // 保留查询参数
        if (this.$route.query && this.$route.query.searchParams) {
            let tempParams = this.$route.query.searchParams
            let params = JSON.parse(tempParams)
            params.regionValue ? (this.regionValue = params.regionValue) : null
            params.productValue
                ? (this.productValue = params.productValue)
                : null

            this.params = utilsHT.deepClone(params)
            delete this.params.regionValue
            delete this.params.productValue
            utils.removeUrlParams('searchParams')
        }
        this.actionUrl = window.context.portal
        this.loadProduct()
        this.getAreaTree()
    },
    mounted() {
        this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
        this.flagList = dictUtils.getDictItemsFromCache('jybs')
        this.addressTypeList = dictUtils.getDictItemsFromCache('azddlx')
    },
    methods: {
        delRegion() {
            if (this.regionValue.length == 0) {
                this.params.areaId = ''
            }
        },
        delProduct() {
            if (this.productValue.length == 0) {
                this.params.productId = ''
            } else {
                let arr = JSON.parse(JSON.stringify(this.productValue))
                this.uploadData.productId = arr.pop()
            }
        },
        openMore() {
            this.showMore = !this.showMore
        },
        getAreaTree() {
            equipmentManage.loadAreaTree(
                {
                    id: '0',
                },
                (res) => {
                    this.treeData = res.value // this.formatData(res.rows)
                    this.$set(this.treeData)
                }
            )
        },
        //导出
        exportKPL() {
            this.exportParam = {
                ...this.queryParam,
            }
            this.exportParam.pageBean = {
                page: 1,
                pageSize: -1,
            }
            //导出直接调用接口
            resourceManage.infoExportExcel(this.exportParam, (res) => { })
        },
        handleAvatarProgress() {
            this.uploading = true
        },
        toEquipmentDetails(val) {
            let path = this.$route.path
            let tempParams = utilsHT.deepClone(this.params) //regionValue
            tempParams.regionValue = this.regionValue
            tempParams.productValue = this.productValue
            console.log(tempParams);

            if (path.indexOf('frontPlat') !== -1) {
                this.$router.push({
                    name: 'EquipmentDetails',
                    query: {
                        id: val.id,
                        name: val.name,
                        status: true,
                        code: val.code,
                        productId: val.productId,
                        isDetails: true,
                        searchParams: JSON.stringify(tempParams),
                    },
                })
            } else {
                this.$router.push({
                    name: 'EquipmentDetailsLink',
                    query: {
                        id: val.id,
                        name: val.name,
                        status: true,
                        code: val.code,
                        productId: val.productId,
                        searchParams: JSON.stringify(tempParams),
                    },
                })
            }
        },
        loadProduct() {
            resourceManage.getProductTree({}, (res) => {
                if (res.state) {
                    this.productData = res.value
                }
            })
        },
        reload() {
            this.loadData()
        },
        // 点击刷新设备数量
        refreshInfo() {
            this.getDeviceInfo()
        },
        // 根据产品id获取设备数量
        getDeviceInfo() {
            let data = {
                productIds: '1651838293752422400,1651838548090822656,1651838677728370688,1651838779897421824'
            }
            equipmentManage.getDeviceInfo(data, (res) => {
                this.deviceInfo = res.value
            })
        },
        loadData(page) {
            this.loadProduct()
            // this.params.productId = '1651837759125463040'
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            if (this.regionValue.length > 0) {
                let arr = JSON.parse(JSON.stringify(this.regionValue))
                this.params.areaId = arr.pop()
            }
            this.queryParam.params = this.params
            this.queryParam.querys = [
                {
                    group: 'main',
                    operation: 'IN',
                    parentGroup: '',
                    property: 'product_Id_',
                    relation: 'AND',
                    value: ['1651838293752422400', '1651838548090822656', '1651838677728370688', '1651838779897421824']
                },
            ]
            this.tableData = []
            resourceManage.loadDevice(this.queryParam, (res) => {
                this.total = res.total
                this.tableData = res.rows
                this.$set(this.tableData)
                this.loading = false
                this.getDeviceInfo()
                this.tableData.forEach((item) => {
                    this.deviceStatus.forEach((val) => {
                        if (item.status == val.value) {
                            item['statusName'] = val.name
                        }
                    })
                    this.addressTypeList.forEach((val) => {
                        if (item.addressType == val.value) {
                            item['addressTypeName'] = val.name
                        }
                    })
                })
            })
            if (this.querys[1].value == '') {
            }
        },
        closeExtend() {
            this.showExtend = false
        },
    },
}
</script>
<style lang="scss" scoped>
.type-tag {
    margin: 0 2px;
}

.refresh:hover {
    cursor: pointer;
}

.refresh {
    font-size: 28px;
    line-height: inherit;
}

::v-deep .el-badge {
    height: 10px;
    position: relative;
    vertical-align: sub;
    display: inline-block;
}

.all-device {
    font-size: 20px;
    padding-left: 5px;
}

.all-device>span {
    font-size: 20px;
    padding-left: 10px;
}

.touchBox {
    position: absolute;
    width: auto;
    border-radius: 10px;
    z-index: 10000;
    padding: 8px 12px;
    box-sizing: border-box;
    background: #242846;
    display: flex;
    justify-content: center;
    flex-direction: column;
    color: #fff;
    display: none;

    .touch-item {
        width: 120px;
    }


}

.statistics {
    flex: 1;
    display: flex;
    justify-content: space-evenly;
    margin-left: 20px;

    .item {
        display: flex;
        align-items: center;

        .icon {
            display: inline-block;
            width: 8px;
            height: 8px;
            margin-right: 6px;
            border-radius: 100%;

            &.color1 {
                background: rgb(19, 206, 102);
            }

            &.color2 {
                background: rgb(230, 162, 60);
            }

            &.color3 {
                background: #4275e8;
            }

            &.color4 {
                background: rgb(255, 73, 73);
            }
        }
    }
}

.onlineItem {
    &:hover {
        .touchBox {
            display: block;
        }
    }
}

.malfunction {
    &:hover {
        .touchBox {
            display: block;
        }
    }
}

a {
    color: #fff;
}

::v-deep .el-badge__content--danger {
    background-color: #ff8000;
}

::v-deep .el-badge__content--warning {
    background-color: #f9c700;
}
</style>
<style lang="scss">
.scorll {
    .el-scrollbar__wrap {
        overflow: scroll;
        height: 100%;
    }
}

.bbsl-table-search {
    cursor: pointer;
}
</style>
